##  SAP Cloud Solutions Modeling Best Practices and Guidelines
  * SAP cloud solutions and all important instances are modeled as an application. Name the application in a way a business user would call it, e.g., SAP S/4HANA Private Cloud, SAP Ariba Sourcing, SAP Ariba Procurement, SAP SuccessFactors HXM Suite, SAP Signavio Process Intelligence, Signavio Process Manager, SAP LeanIX would be level-1 applications and the modules such as Asset Management, Finance, Manufacturing would be level-2 applications.
  * You can leverage SAP LeanIX [SaaS Discovery](https://help.sap.com/docs/leanix/ea/saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "SaaS discovery identifies your organization's SaaS applications by integrating with SSO, SASE, and CASB solutions. It then updates and enriches fact sheets using the reference catalog.") to detect some of the SaaS applications and also identify multiple instances of them.
  * To add more context and accuracy to the model, two IT components should be associated with these applications:
    * One for representing the service itself.
    * One for representing the region of the data center where the service is hosted.
  * Optional: The platform fact sheet can facilitate communication with business stakeholders using commonly understood terminology. It makes sense if your organization has different platforms and if the concept is typically understood by your business stakeholders. For more details, refer to [Platform Modeling Guidelines](https://help.sap.com/docs/leanix/ea/platform-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model platforms. This includes best practices and applicable use cases, and common antipatterns."). If you use the platform fact sheet in the context of your SAP ERP transformation, you might want to create a platform fact sheet “Old ERP” and a Fact Sheet “New ERP - S/4HANA” (for other organizations, it could be “OneERP”).
  * Optional: If you want to map interfaces between your SAP systems to SAP LeanIX, use the [interface](https://help.sap.com/docs/leanix/ea/interface-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model interfaces. This includes best practices and applicable use cases, and common antipatterns.") fact sheet type. This is in particular critical for S/4HANA transformation use cases where you need to understand your organization's integration architecture.


![Modeling Example for SAP Cloud Solutions](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274881d97a4410148caaae1f8e4feaeb_LowRes.png)
Modeling Example for SAP Cloud Solutions
